@@ -1,12 +1,19 @@
 #' Get a Situation Report on System, nflverse Package Versions and Dependencies
 #'
-#' @description This function gives a quick overview of the versions of R and
+#' @description
+#'
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function was deprecated. Please use [`nflreadr::nflverse_sitrep`].
+#'
+#' This function gives a quick overview of the versions of R and
 #'   the operating system as well as the versions of nflverse packages, options,
 #'   and their dependencies. It's primarily designed to help you get a quick
 #'   idea of what's going on when you're helping someone else debug a problem.
 #' @details See [`nflreadr::nflverse_sitrep`] for details.
 #' @inheritDotParams nflreadr::nflverse_sitrep
 #' @inherit nflreadr::nflverse_sitrep
+#' @keywords internal
 #' @examples
 #' \donttest{
 #' \dontshow{
@@ -14,7 +21,7 @@
 #' old_ops <- options(repos = c("CRAN" = "https://cran.rstudio.com/"))
 #' }
 #'
-#' report(recursive = FALSE)
+#' # report(recursive = FALSE)
 #' nflverse_sitrep(pkg = "nflreadr", recursive = TRUE)
 #'
 #' \dontshow{
@@ -23,10 +30,11 @@
 #' }
 #' }
 #' @export
-report <- function(...) nflreadr::nflverse_sitrep(...)
-
-#' @export
-#' @name nflverse_sitrep
-#' @rdname report
-#' @importFrom nflreadr nflverse_sitrep
-NULL
+report <- function(...){
+  lifecycle::deprecate_warn(
+    "5.2.0",
+    "report()",
+    "nflreadr::nflverse_sitrep()"
+  )
+  nflreadr::nflverse_sitrep(...)
+}
